==> igniteui-react-core-16.16.1.tgz: package/esm5/lib/CategoryHighlightLayerDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { __extends } from "tslib";
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { AnnotationLayerDescriptionMetadata } from "./AnnotationLayerDescriptionMetadata";
import { CategoryHighlightLayerDescription } from "./CategoryHighlightLayerDescription";
/**
 * @hidden
 */
var CategoryHighlightLayerDescriptionMetadata = /** @class */ /*@__PURE__*/ (function (_super) {
    __extends(CategoryHighlightLayerDescriptionMetadata, _super);
    function CategoryHighlightLayerDescriptionMetadata() {
        return _super !== null && _super.apply(this, arguments) || this;
    }
    CategoryHighlightLayerDescriptionMetadata.b = function (a) {
        if (CategoryHighlightLayerDescriptionMetadata.a == null) {
            CategoryHighlightLayerDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
            CategoryHighlightLayerDescriptionMetadata.c(CategoryHighlightLayerDescriptionMetadata.a);
        }
        if (a.g(CategoryHighlightLayerDescriptionMetadata.a)) {
            return;
        }
        a.s(CategoryHighlightLayerDescriptionMetadata.a);
    };
    CategoryHighlightLayerDescriptionMetadata.c = function (a) {
        AnnotationLayerDescriptionMetadata.c(a);
        a.item("TargetAxisRef", "(w:TargetAxis,wf:TargetAxis)DataRef::object");
        a.item("UseInterpolation", "Boolean");
        a.item("BandHighlightWidth", "Number:double");
    };
    CategoryHighlightLayerDescriptionMetadata.d = function (a) {
        CategoryHighlightLayerDescriptionMetadata.b(a);
        a.u("CategoryHighlightLayer", function () { return new CategoryHighlightLayerDescription(); });
        a.t("CategoryHighlightLayer", CategoryHighlightLayerDescriptionMetadata.a);
    };
    CategoryHighlightLayerDescriptionMetadata.$t = markType(CategoryHighlightLayerDescriptionMetadata, 'CategoryHighlightLayerDescriptionMetadata');
    CategoryHighlightLayerDescriptionMetadata.a = null;
    return CategoryHighlightLayerDescriptionMetadata;
}(Base));
export { CategoryHighlightLayerDescriptionMetadata };

==> igniteui-react-core-18.1.2.tgz: package/esm5/lib/CategoryHighlightLayerDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { __extends } from "tslib";
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { AnnotationLayerDescriptionMetadata } from "./AnnotationLayerDescriptionMetadata";
import { CategoryHighlightLayerDescription } from "./CategoryHighlightLayerDescription";
/**
 * @hidden
 */
var CategoryHighlightLayerDescriptionMetadata = /** @class */ /*@__PURE__*/ (function (_super) {
    __extends(CategoryHighlightLayerDescriptionMetadata, _super);
    function CategoryHighlightLayerDescriptionMetadata() {
        return _super !== null && _super.apply(this, arguments) || this;
    }
    CategoryHighlightLayerDescriptionMetadata.b = function (a) {
        if (CategoryHighlightLayerDescriptionMetadata.a == null) {
            CategoryHighlightLayerDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
            CategoryHighlightLayerDescriptionMetadata.c(CategoryHighlightLayerDescriptionMetadata.a);
        }
        if (a.j(CategoryHighlightLayerDescriptionMetadata.a)) {
            return;
        }
        a.y(CategoryHighlightLayerDescriptionMetadata.a);
    };
    CategoryHighlightLayerDescriptionMetadata.c = function (a) {
        AnnotationLayerDescriptionMetadata.c(a);
        a.item("TargetAxisRef", "(w:TargetAxis,wf:TargetAxis)DataRef::object");
        a.item("UseInterpolation", "Boolean");
        a.item("BandHighlightWidth", "Number:double");
    };
    CategoryHighlightLayerDescriptionMetadata.d = function (a) {
        CategoryHighlightLayerDescriptionMetadata.b(a);
        a.aa("CategoryHighlightLayer", function () { return new CategoryHighlightLayerDescription(); });
        a.z("CategoryHighlightLayer", CategoryHighlightLayerDescriptionMetadata.a);
    };
    CategoryHighlightLayerDescriptionMetadata.$t = markType(CategoryHighlightLayerDescriptionMetadata, 'CategoryHighlightLayerDescriptionMetadata');
    CategoryHighlightLayerDescriptionMetadata.a = null;
    return CategoryHighlightLayerDescriptionMetadata;
}(Base));
export { CategoryHighlightLayerDescriptionMetadata };
